import 'package:agoradesk/core/theme/theme.dart';
import 'package:agoradesk/core/utils/validator_mixin.dart';
import 'package:agoradesk/core/widgets/branded/password_suffix_icon.dart';
import 'package:flutter/material.dart';

class AgoraPasswordField extends StatefulWidget {
  const AgoraPasswordField({
    Key? key,
    required this.controller,
    this.decoration,
    this.autofocus = false,
    this.enabled = true,
  }) : super(key: key);

  final TextEditingController controller;
  final InputDecoration? decoration;
  final bool autofocus;
  final bool enabled;

  @override
  State<AgoraPasswordField> createState() => _AgoraPasswordFieldState();
}

class _AgoraPasswordFieldState extends State<AgoraPasswordField> with ValidatorMixin {
  bool _obscure = true;
  late InputDecoration decoration;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    if (widget.decoration != null) {
      decoration = widget.decoration!.copyWith(
        suffixIcon: PasswordSuffixIcon(
          passwordVisible: !_obscure,
          onPressed: () => setState(() => _obscure = !_obscure),
        ),
      );
    } else {
      decoration = context.decorationTxtFieldMain.copyWith(
        hintText: context.intl.password,
        errorText: validatePasswordWithNull(widget.controller.text) ? null : '',
        suffixIcon: PasswordSuffixIcon(
          passwordVisible: !_obscure,
          onPressed: () => setState(() => _obscure = !_obscure),
        ),
      );
    }

    return Semantics(
      tooltip: context.intl.password,
      child: TextField(
        controller: widget.controller,
        autofocus: widget.autofocus,
        enabled: widget.enabled,
        obscureText: _obscure,
        decoration: decoration,
        autofillHints: const [AutofillHints.password],
      ),
    );
  }
}
